@@ -32,7 +32,7 @@ fn impl_checkout_server(ast: &syn::DeriveInput) -> TokenStream {
             };
 
             use std::sync::Arc;
-            use checkout_core::dropshot;
+            use checkout_core::dropshot::ApiEndpoint;
             use serde::{Deserialize, Serialize};
             use schemars::JsonSchema;
 
